% --- Source file: man/samc.prediction.Rd ---
\name{BSR.prediction}
\alias{BSR.prediction}
\title{BSR.prediction}
\description{Uses models generated from BSR.sample.model to predict output for the training and testing datasets,
      and to estimate the prediction error based on the training (biased) and testing datasets.}
\usage{
BSR.prediction(train.data, test.data, outdir, response.var, id.var, 
                model.file, gof.file, best.file, op=NULL)}

\arguments{
  \item{train.data}{See \code{\link{BSR}}.}
  \item{test.data}{See \code{\link{BSR}}.}
  \item{outdir}{See \code{\link{BSR}}.}
  \item{response.var}{See \code{\link{BSR}}.}
  \item{id.var}{See \code{\link{BSR}}.}
  \item{model.file}{Output file "out2" from \code{\link{BSR.sample.model}}. }
  \item{gof.file}{Output file "out1" from \code{\link{BSR.sample.model}}. }
  \item{best.file}{Output file "out_best" from \code{\link{BSR.sample.model}}. }
  \item{op}{List of options. See \code{details} for all possible options.}
}
\value{
  A list of the output file names for the predicted training and testing data. Each file contains the colums 
  "PRED.AVG", "PRED.BEST", \code{response.var} and \code{id.var}. The columns "PRED.AVG" and "PRED.BEST" are
  the average and best predicted values for each subject.
}
\details{
  
 \bold{Options list:} \cr

 Below are the names for the options list \code{op}. All names have default values
         if they are not specified. 
  \itemize{
  \item \code{n.burn} Specifies the first \code{n.burn} models from the output to remove. The default is 100.
  \item \code{out.string} Character string to include in the output files. The default is "".
  %\item \code{cut.model} The default is 20. 
  } % END: itemize

}
\seealso{\code{\link{BSR.sample.model}}, \code{\link{BSR.samc}}, \code{\link{BSR}}}
\author{Faming Liang, William Wheeler, Kai Yu}
\examples{

  # Create data
  set.seed(123)
  n    <- 100
  m    <- 50
  y    <- rbinom(n, 1, 0.5)
  id   <- paste("sub_", 1:n, sep="")
  int  <- rep(1, n)
  z1   <- rbinom(n, 1, 0.5)
  z2   <- rbinom(n, 1, 0.5)
  z3   <- runif(n)
  z4   <- runif(n)
  data <- data.frame(y, id, int, z1, z2, z3, z4)

  train.data <- data[1:m, ]
  test.data  <- data[(m+1):n, ]
  outdir     <- "c:/temp/"
  vars0      <- "int"  # The intercept variable
  
  # Options for a small test run
  train.op      <- list(total_iteration=100, warm=10)
  resample.op   <- list(total_iteration=100, warm=10)
  prediction.op <- list(n.burn=2) 
  op            <- list(train.op=train.op, resample.op=resample.op,
                        prediction.op=prediction.op, out.string="test")

  #ret1 <- BSR.samc(train.data, outdir, "y", "id", vars0, groups=NULL,
  #       interactions=NULL,  op=train.op)

  #resample.op$in_models <- ret1$out_models
  #resample.op$in_hist   <- ret1$out_hist
  #ret2 <- BSR.sample.model(train.data, outdir, "y", "id", vars0, groups=NULL,
  #       interactions=NULL,  op=resample.op)

  #model.file <- ret2$out2
  #gof.file   <- ret2$out1
  #best.file  <- ret2$out_best
  #ret <- BSR.prediction(train.data, test.data, outdir, "y", "id", 
  #                model.file, gof.file, best.file, op=prediction.op)

}